@@ -27,7 +27,6 @@ namespace Ampache\Module\Api;
 
 use Ampache\Config\AmpConfig;
 use Ampache\Module\Playback\Stream;
-use Ampache\Module\System\Core;
 use Ampache\Module\Util\ObjectTypeToClassNameMapper;
 use Ampache\Repository\AlbumRepositoryInterface;
 use Ampache\Repository\BookmarkRepositoryInterface;
@@ -162,7 +161,7 @@ class Json5_Data
      * genre_array
      *
      * This returns the formatted 'genre' array for a JSON document
-     * @param list<array{id: int, name: string, is_hidden: int, count: int}> $tags
+     * @param array<int, array{id: int, name: string, is_hidden: int, count: int}> $tags
      */
     private static function genre_array(array $tags): array
     {
@@ -200,32 +199,33 @@ class Json5_Data
      * @param list<int|string> $objects Array of object_ids (Mixed string|int)
      * @param string $type 'artist'|'album'|'song'|'playlist'|'share'|'podcast'|'podcast_episode'|'video'|'live_stream'
      * @param User $user
+     * @param string $auth
      * @param bool $include (add the extra songs details if a playlist or podcast_episodes if a podcast)
      * @return string JSON Object "artist"|"album"|"song"|"playlist"|"share"|"podcast"|"podcast_episode"|"video"|"live_stream"
      */
-    public static function indexes(array $objects, string $type, User $user, bool $include = false): string
+    public static function indexes(array $objects, string $type, User $user, string $auth, bool $include = false): string
     {
         // here is where we call the object type
         switch ($type) {
             case 'song':
                 /** @var string $results */
-                $results = self::songs($objects, $user);
+                $results = self::songs($objects, $user, $auth);
                 break;
             case 'album':
                 $include_array = ($include) ? ['songs'] : [];
 
                 /** @var string $results */
-                $results = self::albums($objects, $include_array, $user);
+                $results = self::albums($objects, $include_array, $user, $auth);
                 break;
             case 'artist':
                 $include_array = ($include) ? ['songs', 'albums'] : [];
 
                 /** @var string $results */
-                $results = self::artists($objects, $include_array, $user);
+                $results = self::artists($objects, $include_array, $user, $auth);
                 break;
             case 'playlist':
                 /** @var string $results */
-                $results = self::playlists($objects, $user, $include);
+                $results = self::playlists($objects, $user, $auth, $include);
                 break;
             case 'share':
                 /** @var string $results */
@@ -233,15 +233,15 @@ class Json5_Data
                 break;
             case 'podcast':
                 /** @var string $results */
-                $results = self::podcasts($objects, $user, $include);
+                $results = self::podcasts($objects, $user, $auth, $include);
                 break;
             case 'podcast_episode':
                 /** @var string $results */
-                $results = self::podcast_episodes($objects, $user);
+                $results = self::podcast_episodes($objects, $user, $auth);
                 break;
             case 'video':
                 /** @var string $results */
-                $results = self::videos($objects, $user);
+                $results = self::videos($objects, $user, $auth);
                 break;
             case 'live_stream':
                 /** @var string $results */
@@ -407,11 +407,12 @@ class Json5_Data
      * @param list<int|string> $artists Artist id's to include
      * @param string[] $include
      * @param User $user
+     * @param string $auth
      * @param bool $encode
      * @param bool $object (whether to return as a named object array or regular array)
      * @return array|string JSON Object "artist"
      */
-    public static function artists(array $artists, array $include, User $user, bool $encode = true, bool $object = true): array|string
+    public static function artists(array $artists, array $include, User $user, string $auth, bool $encode = true, bool $object = true): array|string
     {
         if ((count($artists) > self::$limit || self::$offset > 0) && (self::$limit && $encode)) {
             $artists = array_splice($artists, self::$offset, self::$limit);
@@ -431,14 +432,14 @@ class Json5_Data
             $flag        = new Userflag($artist->id, 'artist');
 
             // Build the Art URL, include session
-            $art_url = AmpConfig::get_web_path() . '/image.php?object_id=' . $artist_id . '&object_type=artist';
+            $art_url = Art::url($artist->id, 'artist', $auth);
 
             // Handle includes
             $albums = (in_array("albums", $include))
-                ? self::albums(self::getAlbumRepository()->getAlbumByArtist($artist->id), [], $user, false)
+                ? self::albums(self::getAlbumRepository()->getAlbumByArtist($artist->id), [], $user, $auth, false)
                 : [];
             $songs = (in_array("songs", $include))
-                ? self::songs(self::getSongRepository()->getByArtist($artist->id), $user, false)
+                ? self::songs(self::getSongRepository()->getByArtist($artist->id), $user, $auth, false)
                 : [];
 
             $JSON[] = [
@@ -479,11 +480,12 @@ class Json5_Data
      * @param list<int|string> $albums Album id's to include
      * @param string[] $include
      * @param User $user
+     * @param string $auth
      * @param bool $encode
      * @param bool $object (whether to return as a named object array or regular array)
      * @return array|string JSON Object "album"
      */
-    public static function albums(array $albums, array $include, User $user, bool $encode = true, bool $object = true): array|string
+    public static function albums(array $albums, array $include, User $user, string $auth, bool $encode = true, bool $object = true): array|string
     {
         if ((count($albums) > self::$limit || self::$offset > 0) && (self::$limit && $encode)) {
             $albums = array_splice($albums, self::$offset, self::$limit);
@@ -508,7 +510,7 @@ class Json5_Data
                 : $album->year;
 
             // Build the Art URL, include session
-            $art_url = AmpConfig::get_web_path() . '/image.php?object_id=' . $album->id . '&object_type=album';
+            $art_url = Art::url($album->id, 'album', $auth);
 
             $objArray = [];
 
@@ -524,7 +526,7 @@ class Json5_Data
 
             // Handle includes
             $songs = (in_array("songs", $include))
-                ? self::songs(self::getSongRepository()->getByAlbum($album->id), $user, false)
+                ? self::songs(self::getSongRepository()->getByAlbum($album->id), $user, $auth, false)
                 : [];
 
             $objArray['time']          = (int)$album->time;
@@ -560,11 +562,12 @@ class Json5_Data
      *
      * @param list<int|string> $playlists Playlist id's to include
      * @param User $user
+     * @param string $auth
      * @param bool $songs
      * @param bool $object (whether to return as a named object array or regular array)
      * @return string
      */
-    public static function playlists(array $playlists, User $user, bool $songs = false, bool $object = true): string
+    public static function playlists(array $playlists, User $user, string $auth, bool $songs = false, bool $object = true): string
     {
         if ((count($playlists) > self::$limit || self::$offset > 0) && self::$limit) {
             $playlists = array_slice($playlists, self::$offset, self::$limit);
@@ -594,7 +597,7 @@ class Json5_Data
                 $object_type    = 'playlist';
                 $playitem_total = $playlist->get_media_count('song');
             }
-            $art_url       = Art::url($playlist->id, $object_type, Core::get_request('auth'));
+            $art_url       = Art::url($playlist->id, $object_type, $auth);
             $playlist_name = $playlist->get_fullname();
             $playlist_user = $playlist->username;
             $playlist_type = $playlist->type;
@@ -795,11 +798,12 @@ class Json5_Data
      *
      * @param list<int|string> $podcasts Podcast id's to include
      * @param User $user
+     * @param string $auth
      * @param bool $episodes include the episodes of the podcast
      * @param bool $object (whether to return as a named object array or regular array)
      * @return string
      */
-    public static function podcasts(array $podcasts, User $user, bool $episodes = false, bool $object = true): string
+    public static function podcasts(array $podcasts, User $user, string $auth, bool $episodes = false, bool $object = true): string
     {
         if ((count($podcasts) > self::$limit || self::$offset > 0) && self::$limit) {
             $podcasts = array_splice($podcasts, self::$offset, self::$limit);
@@ -818,7 +822,7 @@ class Json5_Data
             $rating              = new Rating((int)$podcast_id, 'podcast');
             $user_rating         = $rating->get_user_rating($user->getId());
             $flag                = new Userflag((int)$podcast_id, 'podcast');
-            $art_url             = Art::url((int)$podcast_id, 'podcast', Core::get_request('auth'));
+            $art_url             = Art::url((int)$podcast_id, 'podcast', $auth);
             $podcast_name        = $podcast->get_fullname();
             $podcast_description = $podcast->get_description();
             $podcast_language    = scrub_out($podcast->getLanguage());
@@ -832,7 +836,7 @@ class Json5_Data
             $podcast_episodes    = [];
             if ($episodes) {
                 $results          = $podcast->getEpisodeIds();
-                $podcast_episodes = self::podcast_episodes($results, $user, false);
+                $podcast_episodes = self::podcast_episodes($results, $user, $auth, false);
             }
             // Build this element
             $JSON[] = [
@@ -867,11 +871,12 @@ class Json5_Data
      *
      * @param list<int|string> $podcast_episodes Podcast_Episode id's to include
      * @param User $user
+     * @param string $auth
      * @param bool $encode
      * @param bool $object (whether to return as a named object array or regular array)
      * @return array|string JSON Object "podcast_episode"
      */
-    public static function podcast_episodes(array $podcast_episodes, User $user, bool $encode = true, bool $object = true): array|string
+    public static function podcast_episodes(array $podcast_episodes, User $user, string $auth, bool $encode = true, bool $object = true): array|string
     {
         if ((count($podcast_episodes) > self::$limit || self::$offset > 0) && (self::$limit && $encode)) {
             $podcast_episodes = array_splice($podcast_episodes, self::$offset, self::$limit);
@@ -886,7 +891,7 @@ class Json5_Data
             $rating      = new Rating($episode->id, 'podcast_episode');
             $user_rating = $rating->get_user_rating($user->getId());
             $flag        = new Userflag($episode->id, 'podcast_episode');
-            $art_url     = Art::url($episode->podcast, 'podcast', Core::get_request('auth'));
+            $art_url     = Art::url($episode->podcast, 'podcast', $auth);
             $JSON[]      = [
                 "id" => (string)$episode_id,
                 "title" => $episode->get_fullname(),
@@ -931,18 +936,19 @@ class Json5_Data
      * (Spiffy isn't it!)
      * @param list<int|string> $songs
      * @param User $user
+     * @param string $auth
      * @param bool $encode
      * @param bool $object (whether to return as a named object array or regular array)
      * @return array|string JSON Object "song"
      */
-    public static function songs(array $songs, User $user, bool $encode = true, bool $object = true): array|string
+    public static function songs(array $songs, User $user, string $auth, bool $encode = true, bool $object = true): array|string
     {
         if ((count($songs) > self::$limit || self::$offset > 0) && (self::$limit && $encode)) {
             $songs = array_slice($songs, self::$offset, self::$limit);
         }
 
         Song::build_cache($songs);
-        Stream::set_session($_REQUEST['auth'] ?? '');
+        Stream::set_session($auth);
 
         $JSON           = [];
         $playlist_track = 0;
@@ -958,7 +964,7 @@ class Json5_Data
             $rating      = new Rating($song->id, 'song');
             $user_rating = $rating->get_user_rating($user->getId());
             $flag        = new Userflag($song->id, 'song');
-            $art_url     = Art::url($song->album, 'album', $_REQUEST['auth'] ?? '');
+            $art_url     = Art::url($song->album, 'album', $auth);
             $songMime    = $song->mime;
             $songBitrate = $song->bitrate;
             $play_url    = $song->play_url('', 'api', false, $user->id, $user->streamtoken);
@@ -1053,10 +1059,11 @@ class Json5_Data
      *
      * @param list<int|string> $videos Video id's to include
      * @param User $user
+     * @param string $auth
      * @param bool $object (whether to return as a named object array or regular array)
      * @return string
      */
-    public static function videos(array $videos, User $user, bool $object = true): string
+    public static function videos(array $videos, User $user, string $auth, bool $object = true): string
     {
         if ((count($videos) > self::$limit || self::$offset > 0) && self::$limit) {
             $videos = array_slice($videos, self::$offset, self::$limit);
@@ -1071,7 +1078,7 @@ class Json5_Data
             $rating      = new Rating($video->id, 'video');
             $user_rating = $rating->get_user_rating($user->getId());
             $flag        = new Userflag($video->id, 'video');
-            $art_url     = Art::url($video->id, 'video', Core::get_request('auth'));
+            $art_url     = Art::url($video->id, 'video', $auth);
             $JSON[]      = [
                 "id" => (string)$video->id,
                 "title" => $video->title,
@@ -1106,10 +1113,11 @@ class Json5_Data
      *     track_id: int,
      *     track: int}> $object_ids Object IDs
      * @param User $user
+     * @param string $auth
      * @param bool $object (whether to return as a named object array or regular array)
      * @return string
      */
-    public static function democratic(array $object_ids, User $user, bool $object = true): string
+    public static function democratic(array $object_ids, User $user, string $auth, bool $object = true): string
     {
         if (!is_array($object_ids)) {
             $object_ids = [];
@@ -1128,7 +1136,7 @@ class Json5_Data
 
             $rating      = new Rating($song->id, 'song');
             $user_rating = $rating->get_user_rating($user->getId());
-            $art_url     = Art::url($song->album, 'album', $_REQUEST['auth'] ?? '');
+            $art_url     = Art::url($song->album, 'album', $auth);
             $songMime    = $song->mime;
             $play_url    = $song->play_url('', 'api', false, $user->id, $user->streamtoken);
 
