@@ -102,12 +102,12 @@ final class Albums5Method
             case 'json':
                 Json5_Data::set_offset($input['offset'] ?? 0);
                 Json5_Data::set_limit($input['limit'] ?? 0);
-                echo Json5_Data::albums($results, $include, $user);
+                echo Json5_Data::albums($results, $include, $user, $input['auth']);
                 break;
             default:
                 Xml5_Data::set_offset($input['offset'] ?? 0);
                 Xml5_Data::set_limit($input['limit'] ?? 0);
-                echo Xml5_Data::albums($results, $include, $user);
+                echo Xml5_Data::albums($results, $include, $user, $input['auth']);
         }
 
         return true;
