@@ -129,10 +129,10 @@ final class GetBookmarkMethod
         ob_end_clean();
         switch ($input['api_format']) {
             case 'json':
-                echo Json_Data::bookmarks($results, $include, $all);
+                echo Json_Data::bookmarks($results, $input['auth'], $include, $all);
                 break;
             default:
-                echo Xml_Data::bookmarks($results, $include);
+                echo Xml_Data::bookmarks($results, $input['auth'], $include);
         }
 
         return true;
