@@ -93,13 +93,13 @@ final class UserSmartlistsMethod
                 Json_Data::set_offset((int)($input['offset'] ?? 0));
                 Json_Data::set_limit($input['limit'] ?? 0);
                 Json_Data::set_count($browse->get_total());
-                echo Json_Data::playlists($results, $user, $include);
+                echo Json_Data::playlists($results, $user, $input['auth'], $include);
                 break;
             default:
                 Xml_Data::set_offset((int)($input['offset'] ?? 0));
                 Xml_Data::set_limit($input['limit'] ?? 0);
                 Xml_Data::set_count($browse->get_total());
-                echo Xml_Data::playlists($results, $user, $include);
+                echo Xml_Data::playlists($results, $user, $input['auth'], $include);
         }
 
         return true;
