@@ -47,6 +47,8 @@ final class PlaylistSearchQuery implements QueryInterface
         'regex_not_match',
         'smartlist',
         'starts_with',
+        'user_flag',
+        'user_rating',
     ];
 
     /** @var string[] $sorts */
@@ -177,6 +179,16 @@ final class PlaylistSearchQuery implements QueryInterface
                     $filter_sql = " (`playlist`.`type` = 'public' OR `playlist`.`user`=" . $user_id . " OR `user_playlist_map`.`user_id` IS NOT NULL) AND ";
                 }
                 break;
+            case 'user_flag':
+                $filter_sql = ((int)$value === 0)
+                    ? " `playlist`.`int_id` NOT IN (SELECT `object_id` FROM `user_flag` WHERE `object_type` = `playlist`.`object_type` AND `user` = " . (int)$query->user_id . ") AND "
+                    : " `playlist`.`int_id` IN (SELECT `object_id` FROM `user_flag` WHERE `object_type` = `playlist`.`object_type` AND `user` = " . (int)$query->user_id . ") AND ";
+                break;
+            case 'user_rating':
+                $filter_sql = ((int)$value === 0)
+                    ? " `playlist`.`int_id` NOT IN (SELECT `object_id` FROM `rating` WHERE `object_type` = `playlist`.`object_type` AND `user` = " . (int)$query->user_id . ") AND "
+                    : " `playlist`.`int_id` IN (SELECT `object_id` FROM `rating` WHERE `object_type` = `playlist`.`object_type` AND `user` = " . (int)$query->user_id . " AND `rating` = " . Dba::escape($value) . ") AND ";
+                break;
         }
 
         return $filter_sql;
@@ -196,7 +208,7 @@ final class PlaylistSearchQuery implements QueryInterface
         switch ($field) {
             case 'name':
             case 'title':
-                $sql = "`playlist`.`name`";
+                $sql = "`playlist`.`name`, `playlist`.`id`";
                 break;
             case 'date':
             case 'id':
