@@ -58,7 +58,7 @@ $_SESSION['login'] = true; ?>
 
 <head>
     <!-- Propelled by Ampache | ampache.org -->
-    <meta http-equiv="Content-Type" content="text/html; charset=<?php echo AmpConfig::get('site_charset'); ?>" />
+    <meta http-equiv="Content-Type" content="text/html; charset=<?php echo AmpConfig::get('site_charset', 'UTF-8'); ?>" />
     <meta name="viewport" content="width=device-width, initial-scale=1.0">
     <?php require_once Ui::find_template('stylesheets.inc.php'); ?>
     <title><?php echo scrub_out(AmpConfig::get('site_title')); ?></title>
